==> zmeiapi-0.0.3.tar.gz: zmeiapi-0.0.3/zmeiapi/PinCreators.py <==
__version__ = "0.1.0"
__author__ = 'Vlad Romanenko'


from abc import ABC, abstractmethod


class PinCreator(ABC):
    @abstractmethod
    def __init__(self, number, layer_number, materials, radiuses):
        self.number = number
        self.layer_number = layer_number
        self.materials = materials
        self.radiuses = radiuses
        if len(self.materials) - len(self.radiuses) != 1:
            assert AttributeError("The lenghs of materials and radiuses listsare wrong")

    @abstractmethod
    def create_pin(
            self,
            name: str,
            **kwargs
    ):
        pass


class NumberedPinsCreator(ABC):
    @abstractmethod
    def __init__(self, number, materials, radiuses):
        self.number = number
        self.materials = materials
        self.radiuses = radiuses
        if len(self.materials) - len(self.radiuses) != 1:
            assert AttributeError("The lenghs of materials and radiuses listsare wrong")

    @abstractmethod
    def create_pins(
            self,
            name: str,
            **kwargs
    ):
        pass


class CorePinsCreator(ABC):
    @abstractmethod
    def __init__(self, fas_amount, layers_amount, materials, radiuses):
        self.fas_amount = fas_amount
        self.layers_amount = layers_amount
        self.materials = materials
        self.radiuses = radiuses
        if len(self.materials) - len(self.radiuses) != 1:
            assert AttributeError("The lenghs of materials and radiuses listsare wrong")

    @abstractmethod
    def create_pins(
            self,
            name: str,
            **kwargs
    ):
        pass

==> zmeiapi-0.0.11.tar.gz: zmeiapi-0.0.11/zmeiapi/PinCreators.py <==
__version__ = "0.1.1"
__author__ = 'Vlad Romanenko'


from abc import ABC, abstractmethod
from Logger import logger


class PinCreator(ABC):
    @abstractmethod
    def __init__(self, number, layer_number, materials, radiuses):
        self.number = number
        self.layer_number = layer_number
        self.materials = materials
        self.radiuses = radiuses
        if len(self.materials) - len(self.radiuses) != 1:
            raise AttributeError("The lenghs of materials and radiuses listsare wrong")

    @abstractmethod
    def create_pin(
            self,
            name: str,
            **kwargs
    ):
        pass


class NumberedPinsCreator(ABC):
    @abstractmethod
    def __init__(self, number, materials, radiuses):
        self.number = number
        self.materials = materials
        self.radiuses = radiuses
        if len(self.materials) - len(self.radiuses) != 1:
            raise AttributeError("The lenghs of materials and radiuses listsare wrong")

    @abstractmethod
    def create_pins(
            self,
            name: str,
            **kwargs
    ):
        pass


class CorePinsCreator(ABC):
    @abstractmethod
    def __init__(self, fas_amount, layers_amount, materials, radiuses):
        self.fas_amount = fas_amount
        self.layers_amount = layers_amount
        self.materials = materials
        self.radiuses = radiuses
        if len(self.materials) - len(self.radiuses) != 1:
            raise AttributeError("The lenghs of materials and radiuses listsare wrong")

    @abstractmethod
    def create_pins(
            self,
            name: str,
            **kwargs
    ):
        pass
